/* --------------------------------------------------------------- */
/* ITG3200.c -- gyroscope device I/O for Tollos                    */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/*                                                                 */
/* These definitions provide symbolic names for the ITG3200 3-axis */
/* gyroscope device registers, etc.   The device is attached       */
/* via I2C.                                                        */
/* --------------------------------------------------------------- */

// i2c 7-bit addresses
#define ITG3200_ADDR_0        0x68      // i2c address, AD0=0
#define ITG3200_ADDR_1        0x69      // i2c address, AD0=1

// register names (as per datasheet)
#define ITG3200_WHO_AM_I      0x00
#define ITG3200_SMPLRT_DIV    0x15
#define ITG3200_DLPF_FS       0x16
#define ITG3200_INT_CFG       0x17
#define ITG3200_INT_STATUS    0x1a
#define ITG3200_TEMP_OUT_H    0x1b
#define ITG3200_TEMP_OUT_L    0x1c
#define ITG3200_GYRO_XOUT_H   0x1d
#define ITG3200_GYRO_XOUT_L   0x1e
#define ITG3200_GYRO_YOUT_H   0x1f
#define ITG3200_GYRO_YOUT_L   0x20
#define ITG3200_GYRO_ZOUT_H   0x21
#define ITG3200_GYRO_ZOUT_L   0x22
#define ITG3200_PWR_MGM       0x3e

// full-scale setting
#define FS_SEL                0x18      // 2-bit field
#define FS_2000               0x18      // required setting

// low-pass filter bandwidths
#define DLPF_CFG              0x07      // 3-bit field
#define DLPF_256HZ            0x00
#define DLPF_188HZ            0x01
#define DLPF_98HZ             0x02
#define DLPF_42HZ             0x03
#define DLPF_20HZ             0x04
#define DLPF_10HZ             0x05
#define DLPF_5HZ              0x06

// interrupt configuration
#define IC_ACTL               0x80
#define IC_OPEN               0x40
#define IC_LATCH_INT_EN       0x20
#define IC_INT_ANYRD_2CLEAR   0x10
#define IC_ITG_RDY_EN         0x04
#define IC_RAW_RDY_EN         0x01

// interrupt status
#define IS_ITG_RDY            0x04
#define IS_RAW_DATA_RDY       0x01

// power management
#define PM_H_RESET            0x80
#define PM_SLEEP              0x40
#define PM_STBY_XG            0x20
#define PM_STBY_YG            0x10
#define PM_STBY_ZG            0x08
#define PM_CLK_SRC            0x07      // 3-bit field

// clock source values
#define CLK_SRC_INT           0x00      // internal
#define CLK_SRC_X             0x01      // X gyro
#define CLK_SRC_Y             0x02      // Y gyro
#define CLK_SRC_Z             0x03      // Z gyro
#define CLK_SRC_EXT32K        0x04      // external 32.768 kHz
#define CLK_SRC_EXT19M        0x05      // external 19.2 MHz



